@@ -21,7 +21,20 @@
  * IN THE SOFTWARE.
  */
 
-#include <config.h>
+#include <stdint.h>
+#include <stdlib.h>  // for exit
+#include <string.h>  // for strcmp, memset, size_t
+
+#include <new>
+
+#include <ffi.h>
+#include <girepository.h>
+#include <girffi.h>
+#include <glib-object.h>
+#include <glib.h>
+
+#include "gjs/jsapi-wrapper.h"
+#include "mozilla/Maybe.h"
 
 #include "gi/arg.h"
 #include "gi/boxed.h"
@@ -34,16 +47,11 @@
 #include "gi/param.h"
 #include "gi/union.h"
 #include "gjs/context-private.h"
+#include "gjs/context.h"
 #include "gjs/jsapi-class.h"
-#include "gjs/jsapi-wrapper.h"
+#include "gjs/jsapi-util.h"
 #include "gjs/mem-private.h"
-
-#include <util/log.h>
-
-#include <girepository.h>
-
-#include <errno.h>
-#include <string.h>
+#include "util/log.h"
 
 /* We use guint8 for arguments; functions can't
  * have more than this.
@@ -1507,21 +1515,18 @@ function_to_string (JSContext *context,
                     JS::Value *vp)
 {
     GJS_GET_PRIV(context, argc, vp, rec, to, Function, priv);
-    gchar *string;
-    bool free;
-    bool ret = false;
     int i, n_args, n_jsargs;
     GString *arg_names_str;
     gchar *arg_names;
 
     if (priv == NULL) {
-        string = (gchar *) "function () {\n}";
-        free = false;
-        goto out;
+        JSString* retval = JS_NewStringCopyZ(context, "function () {\n}");
+        if (!retval)
+            return false;
+        rec.rval().setString(retval);
+        return true;
     }
 
-    free = true;
-
     n_args = g_callable_info_get_n_args(priv->info);
     n_jsargs = 0;
     arg_names_str = g_string_new("");
@@ -1544,26 +1549,21 @@ function_to_string (JSContext *context,
     }
     arg_names = g_string_free(arg_names_str, false);
 
+    GjsAutoChar descr;
     if (g_base_info_get_type(priv->info) == GI_INFO_TYPE_FUNCTION) {
-        string = g_strdup_printf(
+        descr = g_strdup_printf(
             "function %s(%s) {\n\t/* wrapper for native symbol %s(); */\n}",
             g_base_info_get_name(priv->info), arg_names,
             g_function_info_get_symbol(priv->info));
     } else {
-        string = g_strdup_printf(
+        descr = g_strdup_printf(
             "function %s(%s) {\n\t/* wrapper for native symbol */\n}",
             g_base_info_get_name(priv->info), arg_names);
     }
 
     g_free(arg_names);
 
- out:
-    if (gjs_string_from_utf8(context, string, rec.rval()))
-        ret = true;
-
-    if (free)
-        g_free(string);
-    return ret;
+    return gjs_string_from_utf8(context, descr, rec.rval());
 }
 
 /* The bizarre thing about this vtable is that it applies to both
