@@ -25,14 +25,24 @@
 #ifndef GI_WRAPPERUTILS_H_
 #define GI_WRAPPERUTILS_H_
 
+#include <stdint.h>
+
+#include <new>
+#include <string>
+
+#include <girepository.h>
+#include <glib-object.h>
+#include <glib.h>
+
+#include "gjs/jsapi-wrapper.h"
+
+#include "gjs/atoms.h"
 #include "gjs/context-private.h"
-#include "gjs/jsapi-class.h"
+#include "gjs/jsapi-class.h"  // IWYU pragma: keep
 #include "gjs/jsapi-util.h"
 #include "gjs/macros.h"
 #include "util/log.h"
 
-G_BEGIN_DECLS
-
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_wrapper_to_string_func(JSContext* cx, JSObject* this_obj,
                                 const char* objtype, GIBaseInfo* info,
@@ -49,10 +59,8 @@ GJS_JSAPI_RETURN_CONVENTION
 bool gjs_wrapper_define_gtype_prop(JSContext* cx, JS::HandleObject constructor,
                                    GType gtype);
 
-G_END_DECLS
-
 namespace InfoType {
-enum Tag { Enum, Interface, Object, Struct };
+enum Tag { Enum, Interface, Object, Struct, Union };
 }
 
 struct GjsTypecheckNoThrow {};
@@ -546,8 +554,6 @@ class GIWrapperBase {
     GJS_JSAPI_RETURN_CONVENTION
     static bool to_string(JSContext* cx, unsigned argc, JS::Value* vp) {
         GJS_GET_WRAPPER_PRIV(cx, argc, vp, args, obj, Base, priv);
-        if (!priv)
-            return false;
         return gjs_wrapper_to_string_func(
             cx, obj, static_cast<const Base*>(priv)->to_string_kind(),
             priv->info(), priv->gtype(), priv->ptr_addr(), args.rval());
@@ -750,7 +756,7 @@ class GIWrapperPrototype : public Base {
     GJS_JSAPI_RETURN_CONVENTION
     bool init(JSContext*) { return true; }
 
-    // The following three methods are private because they are used only in
+    // The following four methods are private because they are used only in
     // create_class().
 
  private:
@@ -863,6 +869,22 @@ class GIWrapperPrototype : public Base {
         return true;
     }
 
+    /*
+     * GIWrapperPrototype::define_static_methods:
+     *
+     * Defines all introspectable static methods on @constructor, including
+     * class methods for objects, and interface methods for interfaces. See
+     * gjs_define_static_methods() for details.
+     *
+     * It requires Prototype to have an info_type_tag member to indicate
+     * the correct template specialization of gjs_define_static_methods().
+     */
+    GJS_JSAPI_RETURN_CONVENTION
+    bool define_static_methods(JSContext* cx, JS::HandleObject constructor) {
+        return gjs_define_static_methods<Prototype::info_type_tag>(
+            cx, constructor, m_gtype, m_info);
+    }
+
  public:
     /**
      * GIWrapperPrototype::create_class:
@@ -923,6 +945,11 @@ class GIWrapperPrototype : public Base {
                 return nullptr;
         }
 
+        if (!priv->is_custom_js_class()) {
+            if (!priv->define_static_methods(cx, constructor))
+                return nullptr;
+        }
+
         JS_SetPrivate(prototype, priv);
         return priv;
     }
