@@ -21,15 +21,14 @@
  * IN THE SOFTWARE.
  */
 
-#ifndef GJS_MODULE_H
-#define GJS_MODULE_H
+#ifndef GJS_MODULE_H_
+#define GJS_MODULE_H_
 
 #include <gio/gio.h>
 
-#include "gjs/macros.h"
-#include "jsapi-wrapper.h"
+#include "gjs/jsapi-wrapper.h"
 
-G_BEGIN_DECLS
+#include "gjs/macros.h"
 
 GJS_JSAPI_RETURN_CONVENTION
 JSObject *
@@ -39,6 +38,4 @@ gjs_module_import(JSContext       *cx,
                   const char      *name,
                   GFile           *file);
 
-G_END_DECLS
-
-#endif  /* GJS_MODULE_H */
+#endif  // GJS_MODULE_H_
